pub struct TextShaderProgram {
program: ShaderProgram,
u_projection: c_int,
u_rendering_pass: c_int,
}Fields
program: ShaderProgramShader program.
u_projection: c_intProjection scale and offset uniform.
u_rendering_pass: c_intRendering pass.
For dual source blending, there are 2 passes; one for background, another for text, similar to the GLSL3 renderer.
If GL_EXT_blend_func_extended is not available, the rendering is split into 4 passes. One is used for the background and the rest to perform subpixel text rendering according to https://github.com/servo/webrender/blob/master/webrender/doc/text-rendering.md.
Rendering is split into three passes.